@@ -13,7 +13,7 @@ module Dotenv
     with(*filenames) do |f|
       ignoring_nonexistent_files do
         env = Environment.new(f)
-        instrument("dotenv.load", :env => env) { env.apply }
+        instrument("dotenv.load", env: env) { env.apply }
       end
     end
   end
@@ -22,7 +22,7 @@ module Dotenv
   def load!(*filenames)
     with(*filenames) do |f|
       env = Environment.new(f)
-      instrument("dotenv.load", :env => env) { env.apply }
+      instrument("dotenv.load", env: env) { env.apply }
     end
   end
 
@@ -31,7 +31,7 @@ module Dotenv
     with(*filenames) do |f|
       ignoring_nonexistent_files do
         env = Environment.new(f)
-        instrument("dotenv.overload", :env => env) { env.apply! }
+        instrument("dotenv.overload", env: env) { env.apply! }
       end
     end
   end
@@ -39,11 +39,11 @@ module Dotenv
   # Internal: Helper to expand list of filenames.
   #
   # Returns a hash of all the loaded environment variables.
-  def with(*filenames, &block)
+  def with(*filenames)
     filenames << ".env" if filenames.empty?
 
     filenames.reduce({}) do |hash, filename|
-      hash.merge! block.call(File.expand_path(filename)) || {}
+      hash.merge!(yield(File.expand_path(filename)) || {})
     end
   end
 
@@ -51,7 +51,7 @@ module Dotenv
     if instrumenter
       instrumenter.instrument(name, payload, &block)
     else
-      block.call
+      yield
     end
   end
 
