@@ -1,5 +1,5 @@
 module Dotenv
-  # This class inherits from Hash and represents the environemnt into which
+  # This class inherits from Hash and represents the environment into which
   # Dotenv will load key value pairs from a file.
   class Environment < Hash
     attr_reader :filename
@@ -14,7 +14,7 @@ module Dotenv
     end
 
     def read
-      File.read(@filename)
+      File.open(@filename, "rb:bom|utf-8", &:read)
     end
 
     def apply
