@@ -9,10 +9,11 @@ module Dotenv
   # exporting of variables.
   class Parser
     @substitutions =
-      Substitutions.constants.map { |const| Substitutions.const_get(const) }
+      [Dotenv::Substitutions::Variable, Dotenv::Substitutions::Command]
 
     LINE = /
       \A
+      \s*
       (?:export\s+)?    # optional export
       ([\w\.]+)         # key
       (?:\s*=\s*|:\s+?) # separator
@@ -23,7 +24,8 @@ module Dotenv
         |               #   or
         [^#\n]+         #   unquoted value
       )?                # value end
-      (?:\s*\#.*)?      # optional comment
+      \s*
+      (?:\#.*)?         # optional comment
       \z
     /x
 
@@ -55,10 +57,10 @@ module Dotenv
         @hash[key] = parse_value(value || "")
       elsif line.split.first == "export"
         if variable_not_set?(line)
-          fail FormatError, "Line #{line.inspect} has an unset variable"
+          raise FormatError, "Line #{line.inspect} has an unset variable"
         end
       elsif line !~ /\A\s*(?:#.*)?\z/ # not comment or blank line
-        fail FormatError, "Line #{line.inspect} doesn't match format"
+        raise FormatError, "Line #{line.inspect} doesn't match format"
       end
     end
 
