@@ -1,10 +1,23 @@
 require "dotenv"
 
+# Fix for rspec rake tasks loading in development
+#
+# Dotenv loads environment variables when the Rails application is initialized.
+# When running `rake`, the Rails application is initialized in development.
+# Rails includes some hacks to set `RAILS_ENV=test` when running `rake test`,
+# but rspec does not include the same hacks.
+#
+# See https://github.com/bkeepers/dotenv/issues/219
+if defined?(Rake.application)
+  is_running_specs = Rake.application.top_level_tasks.grep(/^spec(:|$)/).any?
+  Rails.env = ENV["RAILS_ENV"] ||= "test" if is_running_specs
+end
+
 Dotenv.instrumenter = ActiveSupport::Notifications
 
 # Watch all loaded env files with Spring
 begin
-  require "spring/watcher"
+  require "spring/commands"
   ActiveSupport::Notifications.subscribe(/^dotenv/) do |*args|
     event = ActiveSupport::Notifications::Event.new(*args)
     Spring.watch event.payload[:env].filename if Rails.application
@@ -17,18 +30,12 @@ module Dotenv
   # Dotenv Railtie for using Dotenv to load environment from a file into
   # Rails applications
   class Railtie < Rails::Railtie
-    config.before_configuration { load }
-
     # Public: Load dotenv
     #
     # This will get called during the `before_configuration` callback, but you
     # can manually call `Dotenv::Railtie.load` if you needed it sooner.
     def load
-      Dotenv.load(
-        root.join(".env.local"),
-        root.join(".env.#{Rails.env}"),
-        root.join(".env")
-      )
+      Dotenv.load(*dotenv_files)
     end
 
     # Internal: `Rails.root` is nil in Rails 4.1 before the application is
@@ -43,5 +50,18 @@ module Dotenv
     def self.load
       instance.load
     end
+
+    config.before_configuration { load }
+
+    private
+
+    def dotenv_files
+      [
+        root.join(".env.#{Rails.env}.local"),
+        (root.join(".env.local") unless Rails.env.test?),
+        root.join(".env.#{Rails.env}"),
+        root.join(".env")
+      ].compact
+    end
   end
 end
