@@ -1,3 +1,5 @@
+require "English"
+
 module Dotenv
   module Substitutions
     # Substitute shell commands in a value.
@@ -6,26 +8,27 @@ module Dotenv
     #
     module Command
       class << self
-
         INTERPOLATED_SHELL_COMMAND = /
           (?<backslash>\\)?   # is it escaped with a backslash?
           \$                  # literal $
           (?<cmd>             # collect command content for eval
             \(                # require opening paren
-            ([^()]|\g<cmd>)+  # allow any number of non-parens, or balanced parens (by nesting the <cmd> expression recursively)
+            ([^()]|\g<cmd>)+  # allow any number of non-parens, or balanced
+                              # parens (by nesting the <cmd> expression
+                              # recursively)
             \)                # require closing paren
           )
         /x
 
-        def call(value, env)
+        def call(value, _env)
           # Process interpolated shell commands
           value.gsub(INTERPOLATED_SHELL_COMMAND) do |*|
             # Eliminate opening and closing parentheses
-            command = $~[:cmd][1..-2]
+            command = $LAST_MATCH_INFO[:cmd][1..-2]
 
-            if $~[:backslash]
+            if $LAST_MATCH_INFO[:backslash]
               # Command is escaped, don't replace it.
-              $~[0][1..-1]
+              $LAST_MATCH_INFO[0][1..-1]
             else
               # Execute the command and return the value
               `#{command}`.chomp
@@ -33,7 +36,6 @@ module Dotenv
           end
         end
       end
-
     end
   end
 end
