@@ -14,14 +14,30 @@ describe Dotenv::Parser do
     expect(env("FOO= bar")).to eql("FOO" => "bar")
   end
 
+  it "parses values with leading spaces" do
+    expect(env("  FOO=bar")).to eql("FOO" => "bar")
+  end
+
+  it "parses values with following spaces" do
+    expect(env("FOO=bar  ")).to eql("FOO" => "bar")
+  end
+
   it "parses double quoted values" do
     expect(env('FOO="bar"')).to eql("FOO" => "bar")
   end
 
+  it "parses double quoted values with following spaces" do
+    expect(env('FOO="bar"  ')).to eql("FOO" => "bar")
+  end
+
   it "parses single quoted values" do
     expect(env("FOO='bar'")).to eql("FOO" => "bar")
   end
 
+  it "parses single quoted values with following spaces" do
+    expect(env("FOO='bar'  ")).to eql("FOO" => "bar")
+  end
+
   it "parses escaped double quotes" do
     expect(env('FOO="escaped\"bar"')).to eql("FOO" => 'escaped"bar')
   end
@@ -124,19 +140,28 @@ export OH_NO_NOT_SET')
     expect(env("foo='ba#r'")).to eql("foo" => "ba#r")
   end
 
+  it "parses # in quoted values with following spaces" do
+    expect(env('foo="ba#r"  ')).to eql("foo" => "ba#r")
+    expect(env("foo='ba#r'  ")).to eql("foo" => "ba#r")
+  end
+
+  it "parses empty values" do
+    expect(env("foo=")).to eql("foo" => "")
+  end
+
   if RUBY_VERSION > "1.8.7"
     it "parses shell commands interpolated in $()" do
-      expect(env("ruby_v=$(ruby -v)")).to eql("ruby_v" => RUBY_DESCRIPTION)
+      expect(env("echo=$(echo hello)")).to eql("echo" => "hello")
     end
 
     it "allows balanced parentheses within interpolated shell commands" do
-      expect(env('ruby_v=$(echo "$(echo "$(echo "$(ruby -v)")")")'))
-        .to eql("ruby_v" => RUBY_DESCRIPTION)
+      expect(env('echo=$(echo "$(echo "$(echo "$(echo hello)")")")'))
+        .to eql("echo" => "hello")
     end
 
     it "doesn't interpolate shell commands when escape says not to" do
-      expect(env('ruby_v=escaped-\$(ruby -v)'))
-        .to eql("ruby_v" => "escaped-$(ruby -v)")
+      expect(env('echo=escaped-\$(echo hello)'))
+        .to eql("echo" => "escaped-$(echo hello)")
     end
 
     it "is not thrown off by quotes in interpolated shell commands" do
@@ -156,6 +181,15 @@ export OH_NO_NOT_SET')
       expect(env('FOO="bar\rbaz"')).to eql("FOO" => "bar\rbaz")
     end
 
+    it "escape $ properly when no alphabets/numbers/_  are followed by it" do
+      expect(env("FOO=\"bar\\$ \\$\\$\"")).to eql("FOO" => "bar$ $$")
+    end
+
+    # echo bar $ -> prints bar $ in the shell
+    it "ignore $ when it is not escaped and no variable is followed by it" do
+      expect(env("FOO=\"bar $ \"")).to eql("FOO" => "bar $ ")
+    end
+
     # This functionality is not supported on JRuby or Rubinius
     if (!defined?(RUBY_ENGINE) || RUBY_ENGINE != "jruby") &&
        !defined?(Rubinius)
