@@ -11,7 +11,7 @@ describe Dotenv do
 
       it "defaults to .env" do
         expect(Dotenv::Environment).to receive(:new).with(expand(".env"))
-          .and_return(double(:apply => {}, :apply! => {}))
+          .and_return(double(apply: {}, apply!: {}))
         subject
       end
     end
@@ -23,7 +23,7 @@ describe Dotenv do
         expected = expand("~/.env")
         allow(File).to receive(:exist?) { |arg| arg == expected }
         expect(Dotenv::Environment).to receive(:new).with(expected)
-          .and_return(double(:apply => {}, :apply! => {}))
+          .and_return(double(apply: {}, apply!: {}))
         subject
       end
     end
@@ -111,7 +111,7 @@ describe Dotenv do
   end
 
   describe "with an instrumenter" do
-    let(:instrumenter) { double("instrumenter", :instrument => {}) }
+    let(:instrumenter) { double("instrumenter", instrument: {}) }
     before { Dotenv.instrumenter = instrumenter }
     after { Dotenv.instrumenter = nil }
 
@@ -132,6 +132,19 @@ describe Dotenv do
     end
   end
 
+  describe "Unicode" do
+    subject { fixture_path("bom.env") }
+
+    it "loads a file with a Unicode BOM" do
+      expect(Dotenv.load(subject)).to eql("BOM" => "UTF-8")
+    end
+
+    it "fixture file has UTF-8 BOM" do
+      contents = File.open(subject, "rb", &:read).force_encoding("UTF-8")
+      expect(contents).to start_with("\xEF\xBB\xBF".force_encoding("UTF-8"))
+    end
+  end
+
   def expand(path)
     File.expand_path path
   end
